<?php

class catalog_custom extends catalog {
    /*
     * getBestSellers - функция для получения хитов продаж
     *
     * @limit - количество объектов для показа
     * @field - поле по которому следует сортировать объекты title | price | qty_of_sell
     * @order - порядок сортировки desc | asc | rand
     * @template - не учавствует, так как используется xslt шаблоназатор
     */
    public function getBestSellers($limit = 100, $field = false, $order = false, $template = 'default') {
        /* Формирована для TPL-шаблоназитора*/
        if(!$template) $template = "default"; // Имя шаблона по умолчанию
        $template_line = 'objects_list'; // Имя секции для шаблона TPL
        list($theme) = def_module::loadTemplates('catalog/' . $template, 'elements'); // Загрузка в габлон

        $pages = new selector('pages');

        $pages->types('hierarchy-type')->name('catalog', 'object');

        $pages->option('exclude-nested', true);

        /* Устанавливаются значения поиска */
        $pages->where('qty_of_sell')->more('1');

        if ($field) {
            if($order == 'desc')
                $pages->order($field)->desc();
            elseif ($order == 'asc')
                $pages->order($field)->asc();
            elseif ($order == 'rand')
                $pages->order($field)->rand();
        }

        if(!$field && $order) {
            if($order == 'desc')
                $pages->order('id')->desc();
            elseif ($order == 'asc')
                $pages->order('id')->asc();
            elseif ($order == 'rand')
                $pages->order('id')->rand();
        }

        $lines = Array();
        $total = 0; foreach($pages as $page) {$total ++;}

        $lim = 0;
        foreach($pages as $page) {
            if ($limit == $lim) break;

            $element = umiHierarchy::getInstance()->getElement($page->id);

            $line_arr = Array();
            $line_arr['attribute:id'] = $page->id;
            $line_arr['attribute:link'] = $page->link;
            $line_arr['xlink:href'] = "upage://" . $page->id;

            $line_arr['h1'] = $element->getValue('h1');
            $line_arr['qty_of_sell'] = $element->getValue('qty_of_sell');
            $line_arr['name'] = $page->name;

            $price = $element->getValue('price');
            $line_arr['price'] = number_format($price, 0, '.', ' ');

            $line_arr['photo'] = $element->getValue('photo');

            $lines[] = self::parseTemplate($template_line, $line_arr, $page->id);
            $lim ++;

            umiHierarchy::getInstance()->unloadElement($page->id);
        }

        $block_arr = array();

        if ($total != 0) {
            $block_arr['subnodes:items'] = $lines;
            $block_arr['total'] = $total;
        } else {
            $block_arr['subnodes:items'] = "Нет объектов, которые бы совпадали с указанными параметрами";
            $block_arr['total'] = $total;
        }

        // Возвращаем значение
        return def_module::parseTemplate($theme, $block_arr);
    }

}

?>
